@@ -1,5 +1,5 @@
 package Mock::NoSetup;
-use DBIx::Skinny;
+use DBIx::Skinny setup => +{ check_schema => 0 };
 
 package Mock::NoSetup::Schema;
 use base qw/DBIx::Skinny::Schema::Loader/;
