@@ -1,11 +1,8 @@
 package Mock::Pg;
-use base qw/Class::Data::Inheritable/;
-
-__PACKAGE__->mk_classdata('dbh');
+use DBIx::Skinny setup => +{};
 
 sub setup_test_db {
     my $self = shift;
-    return unless $self->dbh;
     my @statements = (
         qq{
             CREATE TABLE books (
@@ -34,19 +31,18 @@ sub setup_test_db {
             )
         }
     );
-    $self->dbh->do($_) for @statements;
+    $self->do($_) for @statements;
 }
 
 sub clean_test_db {
     my $self = shift;
-    return unless $self->dbh;
     my @statements = (
         q{ DROP TABLE prefectures },
         q{ DROP TABLE genders },
         q{ DROP TABLE authors },
         q{ DROP TABLE books },
     );
-    $self->dbh->do($_) for @statements;
+    $self->do($_) for @statements;
 }
 
 1;
